==> openshift-model-console-6.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskReviewFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleQuickStartTaskReviewFluent<A extends ConsoleQuickStartTaskReviewFluent<A>> extends BaseFluent<A>{
  public ConsoleQuickStartTaskReviewFluent() {
  }
  
  public ConsoleQuickStartTaskReviewFluent(ConsoleQuickStartTaskReview instance) {
    this.copyInstance(instance);
  }
  private String failedTaskHelp;
  private String instructions;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleQuickStartTaskReview instance) {
    instance = (instance != null ? instance : new ConsoleQuickStartTaskReview());
  
    if (instance != null) {
        this.withFailedTaskHelp(instance.getFailedTaskHelp());
        this.withInstructions(instance.getInstructions());
        this.withFailedTaskHelp(instance.getFailedTaskHelp());
        this.withInstructions(instance.getInstructions());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getFailedTaskHelp() {
    return this.failedTaskHelp;
  }
  
  public A withFailedTaskHelp(String failedTaskHelp) {
    this.failedTaskHelp=failedTaskHelp; return (A) this;
  }
  
  public boolean hasFailedTaskHelp() {
    return this.failedTaskHelp != null;
  }
  
  public String getInstructions() {
    return this.instructions;
  }
  
  public A withInstructions(String instructions) {
    this.instructions=instructions; return (A) this;
  }
  
  public boolean hasInstructions() {
    return this.instructions != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartTaskReviewFluent that = (ConsoleQuickStartTaskReviewFluent) o;
    if (!java.util.Objects.equals(failedTaskHelp, that.failedTaskHelp)) return false;
  
    if (!java.util.Objects.equals(instructions, that.instructions)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(failedTaskHelp,  instructions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failedTaskHelp != null) { sb.append("failedTaskHelp:"); sb.append(failedTaskHelp + ","); }
    if (instructions != null) { sb.append("instructions:"); sb.append(instructions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-console-6.9.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskReviewFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleQuickStartTaskReviewFluent<A extends ConsoleQuickStartTaskReviewFluent<A>> extends BaseFluent<A>{
  public ConsoleQuickStartTaskReviewFluent() {
  }
  
  public ConsoleQuickStartTaskReviewFluent(ConsoleQuickStartTaskReview instance) {
    this.copyInstance(instance);
  }
  private String failedTaskHelp;
  private String instructions;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleQuickStartTaskReview instance) {
    instance = (instance != null ? instance : new ConsoleQuickStartTaskReview());
    if (instance != null) {
          this.withFailedTaskHelp(instance.getFailedTaskHelp());
          this.withInstructions(instance.getInstructions());
          this.withFailedTaskHelp(instance.getFailedTaskHelp());
          this.withInstructions(instance.getInstructions());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getFailedTaskHelp() {
    return this.failedTaskHelp;
  }
  
  public A withFailedTaskHelp(String failedTaskHelp) {
    this.failedTaskHelp = failedTaskHelp;
    return (A) this;
  }
  
  public boolean hasFailedTaskHelp() {
    return this.failedTaskHelp != null;
  }
  
  public String getInstructions() {
    return this.instructions;
  }
  
  public A withInstructions(String instructions) {
    this.instructions = instructions;
    return (A) this;
  }
  
  public boolean hasInstructions() {
    return this.instructions != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartTaskReviewFluent that = (ConsoleQuickStartTaskReviewFluent) o;
    if (!java.util.Objects.equals(failedTaskHelp, that.failedTaskHelp)) return false;
    if (!java.util.Objects.equals(instructions, that.instructions)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(failedTaskHelp,  instructions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failedTaskHelp != null) { sb.append("failedTaskHelp:"); sb.append(failedTaskHelp + ","); }
    if (instructions != null) { sb.append("instructions:"); sb.append(instructions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
